/// <reference types="react" />
import { AttributeOrPlaceholder, NullableFiltersOrPlaceholders, AttributesMeasuresOrPlaceholders, ExplicitDrill, OnFiredDrillEvent } from "@gooddata/sdk-ui";
import { IBucketChartProps, ICoreChartProps } from "../../interfaces/index.js";
/**
 * @beta
 */
export interface IRepeaterBucketProps {
    /**
     * Main attribute that sets repeating frequency used for the computation.
     */
    attribute: AttributeOrPlaceholder;
    /**
     * Definition of columns which are sliced by the main attribute.
     */
    columns?: AttributesMeasuresOrPlaceholders;
    /**
     * View by attribute to be used for inline visualizations.
     */
    viewBy?: AttributeOrPlaceholder;
    /**
     * Specify filters to apply on the data to compute with.
     */
    filters?: NullableFiltersOrPlaceholders;
    /**
     * Resolution context for composed placeholders.
     */
    placeholdersResolutionContext?: any;
}
/**
 * @beta
 */
export interface IRepeaterProps extends IBucketChartProps, IRepeaterBucketProps {
    /**
     * Configure drillability; e.g. which parts of the visualization can be interacted with.
     * LIMITATION: For now only attributes in columns can be drilled into.
     */
    drillableItems?: ExplicitDrill[];
    /**
     * Called when user triggers a drill on a visualization.
     */
    onDrill?: OnFiredDrillEvent;
}
/**
 * @beta
 */
export declare const Repeater: (props: IRepeaterProps) => JSX.Element;
export declare function RenderRepeater(props: IRepeaterProps): JSX.Element;
export declare function toCoreRepeaterProps(props: IRepeaterProps): ICoreChartProps;
//# sourceMappingURL=Repeater.d.ts.map