// (C) 2024 GoodData Corporation
import React from "react";
import { useResolveValuesWithPlaceholders, withContexts, IntlTranslationsProvider, IntlWrapper, } from "@gooddata/sdk-ui";
import omit from "lodash/omit.js";
import { CoreRepeater } from "./CoreRepeater.js";
import { constructRepeaterBuckets, constructRepeaterDimensions } from "./internal/repeaterExecution.js";
const WrappedRepeater = withContexts(RenderRepeater);
/**
 * @beta
 */
export const Repeater = (props) => {
    const [attribute, columns, viewBy, filters] = useResolveValuesWithPlaceholders([props.attribute, props.columns, props.viewBy, props.filters], props.placeholdersResolutionContext);
    return React.createElement(WrappedRepeater, { ...props, attribute, columns, viewBy, filters });
};
export function RenderRepeater(props) {
    return (React.createElement(IntlWrapper, { locale: props.locale },
        React.createElement(IntlTranslationsProvider, null, (translationProps) => {
            return React.createElement(CoreRepeater, { intl: translationProps.intl, ...toCoreRepeaterProps(props) });
        })));
}
export function toCoreRepeaterProps(props) {
    const { attribute, columns = [], viewBy } = props;
    const buckets = constructRepeaterBuckets(attribute, columns, viewBy, props.config?.inlineVisualizations);
    const newProps = omit(props, [
        "attribute",
        "columns",
        "viewBy",
        "filters",
        "backend",
    ]);
    return {
        ...newProps,
        execution: createExecution(buckets, props),
        exportTitle: props.exportTitle || "Repeater", // TODO: is this correct? at least translate
    };
}
function createExecution(buckets, props) {
    const { backend, workspace, execConfig } = props;
    const dimensions = constructRepeaterDimensions(buckets);
    return backend
        .withTelemetry("Repeater", props)
        .workspace(workspace)
        .execution()
        .forBuckets(buckets, props.filters)
        .withDimensions(...dimensions)
        .withExecConfig(execConfig);
}
//# sourceMappingURL=Repeater.js.map