// (C) 2022-2024 GoodData Corporation
import { invariant, InvariantError } from "ts-invariant";
import { isMeasure, isAttribute } from "@gooddata/sdk-model";
import { ColumnEventSourceType, } from "../columnWidths.js";
export function getColumnWidths(resizingState) {
    const columnApi = resizingState.columnApi;
    if (!columnApi) {
        return [];
    }
    return [
        ...resizingState.manuallyResizedColumns.map((col) => {
            const column = columnApi.getColumn(col.getColId());
            const item = getSizeItem(resizingState, column);
            const sizeItem = getColumnWidthItem(item, column, {
                value: column.getActualWidth(),
                //TODO: Grow to fit
                allowGrowToFit: false,
            });
            invariant(sizeItem, `unable to find size item by filed ${col.getColId()}`);
            return sizeItem;
        }),
    ];
}
function getSizeItem(resizingState, column) {
    return resizingState.items.find((item) => {
        if (isMeasure(item)) {
            return item.measure.localIdentifier === column.getColDef().field;
        }
        else {
            return item.attribute.localIdentifier === column.getColDef().field;
        }
    });
}
function getColumnWidthItem(item, col, width) {
    if (isAttribute(item)) {
        const attributeIdentifier = item.attribute.localIdentifier;
        if (Number(width.value) === width.value) {
            return {
                attributeColumnWidthItem: {
                    width,
                    attributeIdentifier,
                },
            };
        }
        else {
            throw new InvariantError(`width value for attributeColumnWidthItem has to be number ${col.getColId()}`);
        }
    }
    if (isMeasure(item)) {
        return {
            measureColumnWidthItem: {
                width,
                locators: [createMeasureLocator(item)],
            },
        };
    }
    throw new InvariantError(`could not find header matching ${col.getColId()}`);
}
function createMeasureLocator(measure) {
    return {
        measureLocatorItem: {
            measureIdentifier: measure.measure.localIdentifier,
        },
    };
}
//check
export function isManualResizing(columnEvent) {
    return Boolean(columnEvent?.source === ColumnEventSourceType.UI_DRAGGED && columnEvent.columns);
}
export function isAttributeColumnWidthItem(obj) {
    return obj?.attributeColumnWidthItem !== undefined;
}
export function isMeasureColumnWidthItem(obj) {
    return obj?.measureColumnWidthItem && obj?.measureColumnWidthItem.locators !== undefined;
}
export function isAttributeColumnLocator(obj) {
    return obj?.attributeLocatorItem !== undefined;
}
export function isMeasureColumnLocator(obj) {
    return obj?.measureLocatorItem !== undefined;
}
export function isWeakMeasureColumnWidthItem(obj) {
    return obj?.measureColumnWidthItem && obj?.measureColumnWidthItem.locator !== undefined;
}
export function getManualResizedColumn(resizingState, column) {
    return (resizingState.current.manuallyResizedColumns.find((manuallyResizedColumn) => manuallyResizedColumn.getColId() === column.getColId()) ?? null);
}
//# sourceMappingURL=columnSizing.js.map