import { IResultAttributeHeaderItem, ISeparators } from "@gooddata/sdk-model";
import { DataViewFacade } from "@gooddata/sdk-ui";
/**
 * Key is the localId of the attribute or measure.
 *
 * For row, or column attributes, value is IResultAttributeHeaderItem
 * For slicing attribute, value is array of IResultAttributeHeaderItem.
 * For measure(s), value is array of objects with raw and formatted value.
 */
export type IRepeaterRow = Record<string, IResultAttributeHeaderItem | IResultAttributeHeaderItem[] | RepeaterInlineVisualizationDataPoint[]>;
/**
 * Represents a single data point of the inline visualization in the repeater.
 */
export type RepeaterInlineVisualizationDataPoint = {
    value: number | null;
    formattedValue: string | null;
};
/**
 * Map data view to a structure that can be easily rendered in a table (repeater).
 *
 * Execution is always constructed by the following rules:
 *  - It always contains 1 main row attribute
 *  - It can contain 0..n column attributes
 *  - It can contain 0..n measures
 *  - It can contain 0 or 1 slicing attribute.
 */
export declare function dataViewToRepeaterData(dataViewFacade: DataViewFacade, separators?: ISeparators): IRepeaterRow[];
//# sourceMappingURL=dataViewToRepeaterData.d.ts.map