import { DataViewFacade } from "@gooddata/sdk-ui";
import { dataViewToRepeaterData } from "./dataViewToRepeaterData.js";
const MAX_COLUMNS = 1000;
export const getWindowSize = (numberOfDimensions, startRow = 0, endRow = 100) => {
    const hasTwoDim = numberOfDimensions === 2;
    const offset = hasTwoDim ? [startRow, 0] : [startRow];
    const size = hasTwoDim ? [endRow - startRow, MAX_COLUMNS] : [endRow - startRow];
    return { offset, size };
};
export class AgGridDatasource {
    rowCount;
    dataViewFacade;
    onError;
    config;
    constructor(dataViewFacade, callbacks, config) {
        const [firstDimCount] = dataViewFacade.dataView.count;
        this.dataViewFacade = dataViewFacade;
        this.rowCount = firstDimCount;
        this.onError = callbacks.onError;
        this.config = config;
    }
    async loadExecutionWindow(startRow, endRow) {
        const numberOfDimensions = this.dataViewFacade.meta().dimensions().length;
        const { offset, size } = getWindowSize(numberOfDimensions, startRow, endRow);
        return this.dataViewFacade.result().readWindow(offset, size);
    }
    getRows = (params) => {
        const { startRow, endRow, successCallback, failCallback } = params;
        this.loadExecutionWindow(startRow, endRow)
            .then((result) => {
            const dataViewFacade = DataViewFacade.for(result);
            const transformedResult = dataViewToRepeaterData(dataViewFacade, this.config?.separators);
            successCallback(transformedResult, result.totalCount[0]);
        })
            .catch((error) => {
            console.error("error", { error });
            failCallback();
            this.onError?.(error);
        });
    };
}
//# sourceMappingURL=repeaterAgGridDataSource.js.map