// (C) 2023-2024 GoodData Corporation
import isEqual from "lodash/isEqual.js";
import cx from "classnames";
/**
 * Adds highlighting class to chart points based on provided drill intersections.
 *
 * @param series - chart series
 * @param selectedPoints - selected points defined by drill intersections
 */
export const highlightChartPoints = (series, config) => {
    const { selectedPoints, type } = config;
    if (!selectedPoints?.length) {
        return;
    }
    const borderClassName = ["heatmap", "dependencywheel", "sankey"].includes(type)
        ? "gd-point-highlighted-border"
        : undefined;
    const classNames = cx("gd-point-highlighted", borderClassName);
    series.forEach((seriesItem) => {
        seriesItem.points.forEach((point) => {
            selectedPoints.forEach((selectedPointIntersection) => {
                if (isEqual(point.drillIntersection, selectedPointIntersection)) {
                    /**
                     * In case of waterfall chart, we make sure that the `x` value is not changed.
                     * For some reason it was always changed after any class update and categories were reordered and moved.
                     */
                    const xValueObj = type === "waterfall" ? { x: point.x } : {};
                    point.update({ className: classNames, ...xValueObj }, true);
                }
            });
        });
    });
};
/**
 * Returns classname for the whole series to change opacity of all other points at once.
 */
export const getSeriesHighlightingClassNameObj = (config) => {
    return config?.selectedPoints?.length ? { className: "gd-highlighting" } : {};
};
//# sourceMappingURL=highlightPoints.js.map