import { GRAY, WHITE } from "../_util/color.js";
import { parseValue, unwrap } from "../_util/common.js";
import isNil from "lodash/isNil.js";
const getNullColor = (theme) => theme?.chart?.backgroundColor ?? theme?.palette?.complementary?.c0 ?? WHITE;
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export function getHeatmapSeries(dv, measureGroup, theme) {
    const nullColor = getNullColor(theme);
    const data = [];
    dv.rawData()
        .twoDimData()
        .forEach((rowItem, rowItemIndex) => {
        rowItem.forEach((columnItem, columnItemIndex) => {
            const value = parseValue(String(columnItem));
            const pointData = { x: columnItemIndex, y: rowItemIndex, value };
            if (isNil(value)) {
                data.push({
                    ...pointData,
                    // with latest highcharts version 9.3.0 it was adding border on null values
                    // set border width as 0 to have it as it was on previous versions
                    borderWidth: 0,
                    borderColor: theme?.palette?.complementary?.c4 ?? GRAY,
                    color: nullColor,
                });
            }
            else {
                data.push(pointData);
            }
        });
    });
    return [
        {
            name: measureGroup.items[0].measureHeaderItem.name,
            data,
            turboThreshold: 0,
            yAxis: 0,
            dataLabels: {
                formatGD: unwrap(measureGroup.items[0]).format,
            },
            legendIndex: 0,
            seriesIndex: 0,
        },
    ];
}
//# sourceMappingURL=heatmapChartSeries.js.map