// (C) 2023 GoodData Corporation
import uniqBy from "lodash/uniqBy.js";
import { ColorStrategy, getColorFromMapping, isValidMappedColor, } from "@gooddata/sdk-ui-vis-commons";
import compact from "lodash/compact.js";
export class SankeyChartColorStrategy extends ColorStrategy {
    createColorAssignment(colorPalette, colorMapping, fromAttribute, toAttribute, dv) {
        const attributeItems = compact([...(fromAttribute?.items ?? []), ...(toAttribute?.items ?? [])]);
        const uniqAttributeItems = uniqBy(attributeItems, "attributeHeaderItem.uri");
        const colorAssignment = uniqAttributeItems.map((headerItem, index) => {
            const mappedColor = getColorFromMapping(headerItem, colorMapping, dv);
            const color = mappedColor && isValidMappedColor(mappedColor, colorPalette)
                ? mappedColor
                : {
                    type: "guid",
                    value: colorPalette[index % colorPalette.length].guid,
                };
            return {
                headerItem,
                color,
            };
        });
        return {
            fullColorAssignment: colorAssignment,
        };
    }
}
//# sourceMappingURL=sankeyChartColoring.js.map