import { getAttributeColorAssignment, getColorFromMapping, isValidMappedColor, } from "@gooddata/sdk-ui-vis-commons";
import { MeasureColorStrategy } from "../_chartColoring/measure.js";
import uniq from "lodash/uniq.js";
export class ScatterPlotColorStrategy extends MeasureColorStrategy {
    createColorAssignment(colorPalette, colorMapping, 
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    viewByAttribute, 
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    stackByAttribute, dv, clusterTitle) {
        const isClustering = dv?.dataView?.clusteringConfig?.numberOfClusters > 0;
        const isClusteringError = isClustering && dv?.dataView?.clusteringResult?.clusters?.length === 0;
        const isClusteringLoaded = isClustering && !!dv?.dataView?.clusteringResult && !isClusteringError;
        let colorAssignment;
        if (isClustering && isClusteringLoaded) {
            const uniqueClusters = uniq(dv.dataView.clusteringResult.clusters).sort();
            colorAssignment = uniqueClusters.map((clusterIndex, currentColorPaletteIndex) => {
                const clusterHeaderItem = {
                    colorHeaderItem: {
                        id: `${clusterIndex}`,
                        name: `${clusterTitle} ${clusterIndex}`,
                    },
                };
                const mappedColor = getColorFromMapping(clusterHeaderItem, colorMapping, dv);
                const color = mappedColor && isValidMappedColor(mappedColor, colorPalette)
                    ? mappedColor
                    : {
                        type: "guid",
                        value: colorPalette[currentColorPaletteIndex % colorPalette.length].guid,
                    };
                return {
                    color,
                    headerItem: clusterHeaderItem,
                };
            });
        }
        else if (stackByAttribute) {
            colorAssignment = getAttributeColorAssignment(stackByAttribute, colorPalette, colorMapping, dv);
        }
        else {
            const result = super.createColorAssignment(colorPalette, colorMapping, viewByAttribute, stackByAttribute, dv);
            colorAssignment = result.outputColorAssignment.slice(0, 1);
        }
        return {
            fullColorAssignment: colorAssignment,
            outputColorAssignment: colorAssignment,
        };
    }
}
//# sourceMappingURL=scatterPlotColoring.js.map